Crate chunked_quote

Crate chunked_quote 

[quote] using only one TokenStream.

this crate provide a [quote] inspired macro chunk! that builds TokenStreams though direct appending not object composition.

it support all [quote] features except macro_rules inspired repetetion, and add additional features like control flow and do blocks.

Macros

chunk
append to [TokenStream] code generating the input tokens.
chunk_spanned
[chunk] but with specified span for all tokens not interpolated.
quote
create a [TokenStream] from the input tokens.
quote_spanned
quote! but with specified span for all tokens not interpolated.